+++++++++
Changelog
+++++++++


0.11.0 (21-11-2022)
===================

- Project moved to the ``mesonbuild`` organization
- Determine wheel tags by introspecting the Python interpreter
- Allow users to pass options directly to Meson via the
  ``tools.meson-python.args.{dist,setup,compile,install}`` ``pyproject.toml``
  keys, and the ``{dist,setup,compile,install}-args`` frontend config options
- Use the system ``ninja`` dependency if possible
- Include files generated by ``mesonadd_dist_script`` to sdists
- Use ``tomllib`` on Python>=3.11
- Drop ``wheel`` dependency in favor of in-house solution
- Fix bug where the ``entry_points.txt`` file wasn't being generated
- Fix bug where Cygwin Python extensions were not being noticed


0.10.0 (05-10-2022)
===================

- Ignore the macOS minor version on >=11, to match the behavior with pypa/packaging


0.9.0 (29-09-2022)
==================

- More fixes on ABI tag detection
- Fix incorrect tag on 32-bit Python running on a x86_64 host
- Fix sdist permissions
- Fix incorrect PyPy tags
- Fix ``install_subdirs`` not being included in wheels
- Take ``MACOSX_DEPLOYMENT_TARGET`` into account for the platform tag
- Don't set the rpath on binaries if unneeded


0.8.1 (28-07-2022)
==================

- Fix ``UnboundLocalError`` in tag detection code


0.8.0 (26-07-2022)
==================

- Fix sometimes the incorrect ABI tags being generated
- Add workaround for macOS 11 and 12 installations that are missing a minor version in the platform string


0.7.0 (22-07-2022)
==================

- Fix the wrong Python and ABI tags being generated in Meson 0.63.0
- Fix project license not being included in the project metadata


0.6.0 (21-06-2022)
==================

- Project relicensed to MIT
- Error out when running in an unsupported interpreter
- Fix slightly broken Debian heuristics
- Update ``pep621`` dependency to ``pyproject-metadata``


0.5.0 (26-05-2022)
==================

- Improvements in dependency detections
- Include uncommited changes in sdists


0.4.0 (06-05-2022)
==================

- Set sane default arguments for release builds


0.3.0 (23-03-2022)
==================

- Initial cross-platform support
  - Bundling libraries stioll is only supported on Linux
- Add initial documentation
- The build directory is now located in the project source


0.2.1 (26-02-2022)
==================

- Fix getting the project version dynamically from Meson


0.2.0 (24-01-2022)
==================

- Select the correct ABI and Python tags
- Force Meson to use the correct Python executable
- Replace auditwheel with in-house vendoring mechanism


0.1.2 (12-11-2021)
==================

- Fix auditwheel not being run


0.1.1 (28-10-2021)
==================

- Fix minor compability issue with Python < 3.9


0.1.0 (28-10-2021)
==================

- Initial release
